@@ -217,6 +217,8 @@ Classes
    :toctree: ../stubs/
 
    IBMRuntimeService
+   IBMEstimator
+   IBMSampler
    IBMBackend
    RuntimeJob
    RuntimeProgram
@@ -239,6 +241,16 @@ from .exceptions import *
 from .utils.utils import setup_logger
 from .version import __version__
 
+from .ibm_estimator import IBMEstimator
+from .ibm_sampler import IBMSampler
+
+# TODO remove when terra code is released
+from .qiskit.primitives import (
+    BaseEstimator,
+    EstimatorResult,
+    BaseSampler,
+    SamplerResult,
+)
 
 # Setup the logger for the IBM Quantum Provider package.
 logger = logging.getLogger(__name__)
